==> qtjambi-qt3drender-6.2.7-sources.jar: io/qt/qt3d/render/QEnvironmentLight.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulate an environment light object in a Qt 3D scene</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html">Qt3DRender::QEnvironmentLight</a></p>
 */
public class QEnvironmentLight extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QEnvironmentLight.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::irradianceChanged(Qt3DRender::QAbstractTexture*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="irradiance")
    public final Signal1<io.qt.qt3d.render.QAbstractTexture> irradianceChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::specularChanged(Qt3DRender::QAbstractTexture*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="specular")
    public final Signal1<io.qt.qt3d.render.QAbstractTexture> specularChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QEnvironmentLight(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QEnvironmentLight() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QEnvironmentLight(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QEnvironmentLight instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::irradiance()const</a></p>
     */
    @io.qt.QtPropertyReader(name="irradiance")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAbstractTexture irradiance(){
        return irradiance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QAbstractTexture irradiance_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::setIrradiance(Qt3DRender::QAbstractTexture*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="irradiance")
    public final void setIrradiance(io.qt.qt3d.render.QAbstractTexture irradiance){
        setIrradiance_native_Qt3DRender_QAbstractTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(irradiance));
    }
    
    private native void setIrradiance_native_Qt3DRender_QAbstractTexture_ptr(long __this__nativeId, long irradiance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::setSpecular(Qt3DRender::QAbstractTexture*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="specular")
    public final void setSpecular(io.qt.qt3d.render.QAbstractTexture specular){
        setSpecular_native_Qt3DRender_QAbstractTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(specular));
    }
    
    private native void setSpecular_native_Qt3DRender_QAbstractTexture_ptr(long __this__nativeId, long specular);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::specular()const</a></p>
     */
    @io.qt.QtPropertyReader(name="specular")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAbstractTexture specular(){
        return specular_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QAbstractTexture specular_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QEnvironmentLight(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QEnvironmentLight(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QEnvironmentLight instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.1-sources.jar: io/qt/qt3d/render/QEnvironmentLight.java <==
package io.qt.qt3d.render;


/**
 * <p>Encapsulate an environment light object in a Qt 3D scene</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html">Qt3DRender::QEnvironmentLight</a></p>
 */
public class QEnvironmentLight extends io.qt.qt3d.core.QComponent
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QEnvironmentLight.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::irradianceChanged(Qt3DRender::QAbstractTexture*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="irradiance")
    public final Signal1<io.qt.qt3d.render.QAbstractTexture> irradianceChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::specularChanged(Qt3DRender::QAbstractTexture*)</a></p>
     */
    @io.qt.QtPropertyNotify(name="specular")
    public final Signal1<io.qt.qt3d.render.QAbstractTexture> specularChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QEnvironmentLight(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QEnvironmentLight() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QEnvironmentLight(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QEnvironmentLight instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::irradiance()const</a></p>
     */
    @io.qt.QtPropertyReader(name="irradiance")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAbstractTexture irradiance(){
        return irradiance_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QAbstractTexture irradiance_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#irradiance-prop">Qt3DRender::QEnvironmentLight::setIrradiance(Qt3DRender::QAbstractTexture*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="irradiance")
    public final void setIrradiance(io.qt.qt3d.render.QAbstractTexture irradiance){
        setIrradiance_native_Qt3DRender_QAbstractTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(irradiance));
    }
    
    private native void setIrradiance_native_Qt3DRender_QAbstractTexture_ptr(long __this__nativeId, long irradiance);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::setSpecular(Qt3DRender::QAbstractTexture*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="specular")
    public final void setSpecular(io.qt.qt3d.render.QAbstractTexture specular){
        setSpecular_native_Qt3DRender_QAbstractTexture_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(specular));
    }
    
    private native void setSpecular_native_Qt3DRender_QAbstractTexture_ptr(long __this__nativeId, long specular);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qenvironmentlight.html#specular-prop">Qt3DRender::QEnvironmentLight::specular()const</a></p>
     */
    @io.qt.QtPropertyReader(name="specular")
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QAbstractTexture specular(){
        return specular_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QAbstractTexture specular_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QEnvironmentLight(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QEnvironmentLight(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QEnvironmentLight instance, QDeclarativeConstructor constructor);
    
}
